@@ -37,6 +37,14 @@ class DevicePathElem:
         self.subtype = 0x04	# filepath
         self.data    = bytes(ucs16.from_string(str(filepath)))
 
+    def set_gpt(self, pnr, poff, plen, guid):
+        self.devtype = 0x04	# media
+        self.subtype = 0x01	# hard drive
+        self.data = b''
+        self.data += struct.pack('=LQQ', pnr, poff, plen)
+        self.data += guids.parse_str(guid).bytes_le
+        self.data += struct.pack('=BB', 0x02, 0x02)
+
     def fmt_hw(self):
         if self.subtype == 0x01:
             (func, dev) = struct.unpack_from('=BB', self.data)
@@ -120,6 +128,21 @@ class DevicePathElem:
             return self.fmt_media()
         return f'Unknown(type=0x{self.devtype:x},subtype=0x{self.subtype:x})'
 
+    def __eq__(self, other):
+        if self.devtype != other.devtype:
+            return False
+        if self.subtype != other.subtype:
+            return False
+
+        if self.devtype == 0x04 and self.subtype == 0x04:
+            # FilePath -> compare case-insensitive
+            p1 = str(ucs16.from_ucs16(self.data)).lower()
+            p2 = str(ucs16.from_ucs16(other.data)).lower()
+            return p1 == p2
+
+        return self.data == other.data
+
+
 class DevicePath(collections.UserList):
     """ class reprsenting an efi device path """
 
@@ -159,3 +182,13 @@ class DevicePath(collections.UserList):
 
     def __str__(self):
         return "/".join(map(str, list(self)))
+
+    def __eq__(self, other):
+        if len(self) != len(other):
+            return False
+        idx = 0
+        while idx < len(self):
+            if self[idx] != other[idx]:
+                return False
+            idx += 1
+        return True
